/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: IClusterManager.java 348 2011-09-28 13:45:02Z chou $
 *
 */

package org.ow2.sirocco.cloudmanager.clustermanager.api;

import java.util.Date;
import java.util.List;
import java.util.Map;

import org.ow2.sirocco.vmm.api.ResourcePartitionMXBean;
import org.ow2.sirocco.vmm.api.VMMException;
import org.ow2.sirocco.vmm.api.VirtualMachineMXBean;
import org.ow2.sirocco.vmm.api.monitoring.PerfMetric;

public interface IClusterManager {
    // void createVirtualMachine(final VMConfigSpec spec, Map<String, String>
    // constraints, AllocationMode allocationMode)
    // throws VMMException;

    void createVirtualMachine(VirtualMachineCreationSpec spec, Map<String, String> constraints, AllocationMode allocationMode,
        boolean startVM) throws VMMException;

    void uploadVMImage(String url, String format, String name, String description, String checkSum) throws VMMException;

    /**
     * @param spec
     * @param handback
     * @return volume's providerId
     * @throws VMMException
     */
    String createVolume(VolumeSpec spec, Object handback) throws VMMException;

    void destroyVolume(String providerId) throws VMMException;

    void attachVolumeToVM(String vmProviderId, String volumeId) throws VMMException;

    void detachVolumeFromVM(String vmProviderId, String volumeId) throws VMMException;

    String[] getVMVolumes(String vmProviderId) throws VMMException;

    void stopVirtualMachine(String vmRef) throws VMMException;

    void destroyVirtualMachine(String vmRef) throws VMMException;

    void rebootVirtualMachine(String vmRef) throws VMMException;

    void pauseVirtualMachine(String vmRef) throws VMMException;

    void unpauseVirtualMachine(String vmRef) throws VMMException;

    void createImageFromVirtualMachine(String providerId, Integer vmiId, final String vmiName, final String vmiDescription)
        throws VMMException;

    void startVirtualMachine(String vmRef) throws VMMException;

    void migrateVirtualMachine(String vmRef, String hostRef) throws VMMException;

    String getVirtualMachineConsole(String vmRef) throws VMMException;

    List<String> getLocations();

    Domain getResourceTree();

    List<ServerPool> getServerPools();

    ResourcePartitionMXBean getResourcePartition(final AllocationMode allocationMode, final String hypervisorType,
        final String location);

    List<ResourcePartitionInfo> getResourcePartitions();

    List<Host> getHostRefFromServerPool(String poolRef);

    VirtualMachineMXBean getVirtualMachineMBean(String vmRef);

    String[] getVirtualMachineRefByHost(final String hostRef);

    Map<String, Long> getVirtualMachineSchedulingParams(String vmRef);

    long getVirtualMachineMemoryUsedMB(String vmRef);

    float getVirtualMachineCPULoad(String vmRef);

    PerfMetricBase[] getHostPerfMetrics(final String hostId, final String metricId, final Date startTime, final Date endTime)
        throws VMMException;

    PerfMetricBase[] getVirtualMachinePerfMetrics(final String vmLabel, final String metricId, final Date startTime,
        final Date endTime) throws VMMException;

    void destroyVMImage(String providerId) throws VMMException;

    PerfMetricInfo[] getUserPerfMetricInfos(String id);

    PerfMetricInfo[] getProjectPerfMetricInfos(String id);

    PerfMetricInfo[] getVirtualMachinePerfMetricInfos();

    PerfMetricInfo[] getHostPerfMetricInfos();

    PerfMetricInfo[] getServerPoolPerfMetricInfos();

    PerfMetricInfo[] getDomainPerfMetricInfos();

    PerfMetric getHostPerfMetric(String id, PerfMetricInfo info);

    PerfMetric getServerPoolPerfMetric(String id, PerfMetricInfo info);

    PerfMetric getDomainPerfMetric(String id, PerfMetricInfo info); // don't
                                                                    // work

    PerfMetric getVirtualMachinePerfMetric(String id, PerfMetricInfo pmitmp); // DW

    PerfMetric[] getHostPerfMetrics(String id, PerfMetricInfo info, final Date startTime, final Date endTime);

    PerfMetric[] getServerPoolPerfMetrics(String id, PerfMetricInfo info, final Date startTime, final Date endTime);

    PerfMetric[] getDomainPerfMetrics(String id, PerfMetricInfo info, final Date startTime, final Date endTime); // DW

    PerfMetricInfo getPerfMetricInfoById(Integer valueOf, String type);

}
