/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: PerfCompositeMetric.java 36 2011-06-20 14:38:41Z dangtran $
 *
 */

package org.ow2.sirocco.cloudmanager.clustermanager.api;

import java.io.Serializable;
import java.util.Date;

/**
 * Composite performance metric value.
 */
public class PerfCompositeMetric extends PerfMetricBase implements Serializable {
    private static final long serialVersionUID = -1359638384384125957L;

    private float[] values;

    private String[] components;

    /**
     * Constructs a PerfCompositeMetric
     * 
     * @param timeStamp the time at which the metric value was measured
     * @param values the values of every component of the metric
     * @param components the names of every component of the metric
     */
    public PerfCompositeMetric(final Date timeStamp, final float values[], final String[] components) {
        super(timeStamp);
        this.values = values;
        this.components = components;
    }

    /**
     * Returns the values of every component of the metric
     * 
     * @return the values of every component of the metric
     */
    public float[] getValues() {
        return this.values;
    }

    /**
     * Returns the names of every component of the metric
     * 
     * @return the names of every component of the metric
     */
    public String[] getComponents() {
        return this.components;
    }

    public void setValues(final float[] values) {
        this.values = values;
    }

    public void setComponents(final String[] components) {
        this.components = components;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("(time=" + this.timeStamp);
        for (int i = 0; i < this.values.length; i++) {
            sb.append(",(" + this.components[i] + "," + this.values[i] + ")");
        }
        return sb.append(")").toString();
    }

}
